/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License version 3, as published 
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranties of 
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
 * PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along 
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Alberto Mardegan <alberto.mardegan@canonical.com>
 */

public class TestPlugin : Ap.Plugin {
    public Gtk.Widget widget_to_build;

    public TestPlugin(Ag.Account account) {
        Object(account: account);
    }

    public override unowned Gtk.Widget build_widget () {
        return widget_to_build;
    }
}

public class TestApplicationPlugin : Ap.ApplicationPlugin {
    public Gtk.Widget widget_to_build;

    public TestApplicationPlugin(Ag.Application application,
                                 Ag.Account account) {
        Object(account: account, application: application);
    }

    public override unowned Gtk.Widget build_widget () {
        return widget_to_build;
    }
}

int main (string[] args)
{
    Gtk.test_init (ref args);

    Test.add_func ("/libaccount-plugin/plugin/create", accountplugin_create);
    Test.add_func ("/libaccount-plugin/application-plugin/create",
                   applicationplugin_create);

    Test.run ();

    return Posix.EXIT_SUCCESS;
}

void accountplugin_create ()
{
    var manager = new Ag.Manager ();
    var account = manager.create_account ("MyProvider");

    var plugin = new TestPlugin (account);

    assert (plugin.account == account);
    assert (plugin.get_account () == account);

    plugin.need_authentication = true;
    assert (plugin.need_authentication == true);
    assert (plugin.get_need_authentication () == true);

    /* Make sure that the virtual method is called */
    plugin.widget_to_build = new Gtk.Label ("Hello world!");
    assert (plugin.build_widget () == plugin.widget_to_build);
}

void applicationplugin_create ()
{
    var manager = new Ag.Manager ();
    var account = manager.create_account ("MyProvider");
    var application = manager.get_application ("Gallery");
    assert (application != null);

    var plugin = new TestApplicationPlugin (application, account);

    assert (plugin.account == account);
    assert (plugin.get_account () == account);
    assert (plugin.application == application);
    assert (plugin.get_application () == application);

    /* Make sure that the virtual method is called */
    plugin.widget_to_build = new Gtk.Label ("Hello world!");
    assert (plugin.build_widget () == plugin.widget_to_build);
}
